@@ -1,6 +1,6 @@
 package Net::OAuth::LP::Models;
 
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 use strictures 1;
 use Moo::Role;
@@ -8,9 +8,8 @@ use Method::Signatures;
 
 has 'c' => (is => 'rw',);
 
-method find         { }
-method find_by_link { }
-method filter       { }
+method fetch         { }
+method fetch_by_link { }
 
 method search ($path, $segments) {
     my $query = $self->c->__query_from_hash($segments);
@@ -18,10 +17,6 @@ method search ($path, $segments) {
     $self->c->get($uri);
 }
 
-method resource ($resource_link) {
-    $self->c->get($resource_link);
-}
-
 1;
 
 __END__
@@ -42,27 +37,24 @@ Client attribute to perform authenticated requests.
 
 =head1 METHODS
 
-=head2 B<find>
+=head2 B<fetch>
 
-Override in extended models.
+Override in extended models to get a resource by item.
 
-=head2 B<find_by_link>
+=head2 B<fetch_by_link>
 
-Override in extended models.
+Override in extended models to get a resource by resource link.
 
 =head2 B<search>
 
 Performs a search request against the target distribution.
 
-    $lp->search('ubuntu', { 'ws.op' => 'searchTasks',
-                            'ws.size' => '10',
-                            'status' => 'New' });
-
-=head2 B<resource>
-
-Access resource endpoints directly, however, once API is feature complete
-this method shouldn't need to be referenced.
-
-    $lp->resource('launchpad_resource_link');
+    $modal->search(
+        'ubuntu',
+        {   'ws.op'   => 'searchTasks',
+            'ws.size' => '10',
+            'status'  => 'New'
+        }
+    );
 
 =cut
